import Pair from './Pair';
export default class Cache {
    private cache;
    private options;
    constructor(options?: {
        maxSize?: number;
        maxAge?: number;
        checkInterval?: number;
        removeOldest?: boolean;
    });
    /**
     * Get a value from the cache. If the key is not found
     * in the cache, `null` is returned.
     *
     * @param {string} key The key to get the value for.
     * @returns {any | null} The value for the key, or `null` if the key is not found.
     * @public
     */
    get(key: string): any | null;
    /**
     * Set a value in the cache.
     *
     * @param {string} key The key of the entry.
     * @param {any} value The value to set it to.
     * @returns {Cache} The updated cache.
     * @public
     */
    set(key: string, value: any, options?: any): Cache;
    /**
     * Check if the cache contains a key.
     *
     * @param {string} key The key of the entry.
     * @returns {boolean} `true` if the key is found, `false` otherwise.
     * @public
     */
    has(key: string): boolean;
    /**
     * Remove a key from the cache.
     *
     * @param {string} key The key of the entry.
     * @returns {Cache} The updated cache.
     * @public
     */
    remove(key: string): Cache;
    /**
     * Get the amount of entries in the cache.
     *
     * @returns {number} The size of the cache.
     * @public
     */
    size(): number;
    /**
     * Get an object of the entries in the cache. The
     * key is the key of the entry, and the value is
     * the value of the entry.
     *
     * @returns {{ [key: string]: any }} The array.
     * @public
     */
    entries(): {
        [key: string]: any;
    };
    /**
     * Get an array of the entries in the cache.
     *
     * @returns {Pair<string, any>[]} The array.
     * @public
     */
    array(): Pair<string, any>[];
    /**
     * Clear the cache and its contents.
     *
     * @returns {Cache} The updated cache.
     * @public
     */
    clear(): Cache;
    /**
     * Make space in the cache for a new entry. You
     * **probably shouldn't** run this method directly
     * unless you know **EXACTLY** what you're doing.
     *
     * @returns {void}
     * @public
     */
    makeSpace(options?: any): void;
}
