import { EventResolvable } from '../util/Types';
import GuildBlock from './blocks/GuildBlock';
import UserBlock from './blocks/UserBlock';
import ClientUser from './ClientUser';
import Intents from './Intents';
import Websocket from './websocket/Websocket';
export default class Client {
    private valid;
    token: string;
    ws: Websocket;
    me: ClientUser | null;
    options: {
        intents: Intents;
        debug: boolean;
    };
    readonly guilds: GuildBlock;
    readonly users: UserBlock;
    private events;
    constructor(options?: any);
    /**
     * Add an event listener.
     *
     * @param {EventResolvable} event The event name.
     * @param {Function} listener The function to call when the event is emitted.
     * @returns {void}
     */
    listen(event: EventResolvable, callback: Function): void;
    /**
     * Undind an event listener.
     *
     * @param {EventResolvable} event The event name to unbind.
     * @returns {void}
     */
    unbind(event: EventResolvable): void;
    /**
     * Emit an event.
     *
     * @param {EventResolvable} event The event name.
     * @param {any} data The event data to pass to the listener.
     * @returns {void}
     */
    emit(event: EventResolvable, ...args: any[]): void;
    /**
     * Connect to the Discord gateway.
     *
     * @param {string} token Your bot's token.
     * @returns {void}
     */
    connect(token: string): void;
    /**
     * Emit a log in debug mode.
     *
     * @param {any} message The log message.
     * @returns {void}
     */
    debug(...message: any[]): void;
    /**
     * Emit a warning in debug mode.
     *
     * @param {any} message The warning message.
     * @returns {void}
     */
    warn(...message: any[]): void;
    /**
     * Invalidate the client, forcing the user to restart
     * the process to use it. Once called, this cannot be
     * undone (mostly because it would defeat the entire
     * purpose of this function).
     *
     * @returns {void}
     * @public
     */
    _invalidate(): void;
}
