"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Constants_1 = require("../util/Constants");
const BaseUser_1 = __importDefault(require("./BaseUser"));
const HTTPUser_1 = __importDefault(require("./http/HTTPUser"));
const OptionError_1 = __importDefault(require("../errors/OptionError"));
class ClientUser extends BaseUser_1.default {
    constructor(client, data) {
        super(client, data);
        this.bot = true;
        this.system = false;
        this.build(data);
    }
    build(data) {
        this.username = data.username ?? 'Unknown';
        this.discriminator = data.discriminator ?? '0000';
        this.tag = `${this.username}#${this.discriminator}`;
        this.flags = data.public_flags ?? 0;
        if ('avatar' in data) {
            this.avatar = data.avatar;
        }
        if ('banner' in data) {
            this.banner = data.banner;
        }
        if ('accent_color' in data) {
            this.accent_color = data.accent_color;
        }
    }
    updatePresence(options) {
        options = options ?? {};
        if (options.activity) {
            options.activity.name = 'on Birb.JS';
            options.activity.type = Constants_1.ActivityType.PLAYING;
        }
        this.client.ws.send({
            op: 3,
            d: {
                status: options.status ?? 'online',
                afk: options.afk ?? false,
                activity: options.activity ? [options.activity] : null,
                since: options.afk ? Date.now() : null,
            },
        });
    }
    async setName(name) {
        if (name === undefined) {
            throw new OptionError_1.default('name [at 0] must be provided');
        }
        if (typeof name !== 'string') {
            throw new OptionError_1.default('name [at 0] must be a string with a length of at least 1 character');
        }
        await HTTPUser_1.default.modifyCurrent(this.client, { username: name });
    }
}
exports.default = ClientUser;
