import Guild from './Guild';
import BaseUser from './BaseUser';
import GuildMemberRoleBlock from './blocks/GuildMemberRoleBlock';
import Client from './Client';
export default class GuildMember {
    client: Client;
    readonly id: string;
    guild: Guild;
    user: BaseUser | null;
    originalUser: any;
    full: boolean;
    nick: string | null;
    avatar: string | null;
    joinedAt: Date | null;
    deafened: boolean;
    muted: boolean;
    timedOutUntil: Date | null;
    pendingMembershipScreening: boolean;
    roles: GuildMemberRoleBlock;
    constructor(client: Client, data: any, guild: Guild);
    private build;
    /**
     * Check if this GuildMember is in timeout.
     *
     * @returns {boolean} Whether this GuildMember is in timeout.
     */
    isInTimeout(): boolean;
    /**
     * Set this GuildMember's muted status.
     *
     * @param {boolean} deafen The new muted status.
     * @param {String} [reason] The reason for modifying this GuildMember.
     * @returns {Promise<void>} A Promise that voids when the GuildMember has been changed.
     */
    setMute(mute: boolean, reason?: string): Promise<void>;
    /**
     * Set this GuildMember's deafened status.
     *
     * @param {boolean} deafen The new deafened status.
     * @param {String} [reason] The reason for modifying this GuildMember.
     * @returns {Promise<void>} A Promise that voids when the GuildMember has been changed.
     */
    setDeafen(deafen: boolean, reason?: string): Promise<void>;
    /**
     * Set this GuildMember's nickname.
     *
     * @param {number} nickname The new nickname.
     * @param {String} [reason] The reason for modifying this GuildMember.
     * @returns {Promise<void>} A Promise that voids when the GuildMember has been changed.
     */
    setNick(nickname: string, reason?: string): Promise<void>;
    /**
     * Kick the GuildMember.
     *
     * @param {String} [reason] The reason for kicking this GuildMember.
     * @returns {Promise<void>} A Promise that voids when the GuildMember has been changed.
     */
    kick(reason?: string): Promise<void>;
    /**
     * Ban the GuildMember.
     *
     * @param {number} [daysToPrune=0] The amount of days of messages to prune.
     * @param {String} [reason] The reason for banning this GuildMember.
     * @returns {Promise<void>} A Promise that voids when the GuildMember has been changed.
     */
    ban(daysToPrune: number, reason?: string): Promise<void>;
    /**
     * Modify the GuildMember.
     *
     * @param {Object} data The data to send to the Discord API.
     * @param {String} [reason] The reason for modifying this GuildMember.
     * @returns {Promise<void>} A Promise that voids when the GuildMember has been changed.
     */
    modify(data: Object, reason?: string): Promise<void>;
    _waitForFull(): Promise<GuildMember>;
    private set;
}
