"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("..");
class Message {
    constructor(client, data) {
        this.client = null;
        this.content = null;
        this.webhookId = null;
        this.guild = null;
        this.author = null;
        this.member = null;
        this.channel = null;
        this.baseAuthor = null;
        this.client = client;
        this.id = data.id;
        this.build(data);
    }
    build(data) {
        this.baseAuthor = data.author || null;
        if ('content' in data) {
            this.content = data.content;
        }
        if ('webhook_id' in data) {
            this.webhookId = data.webhook_id;
        }
        if ('guild_id' in data) {
            this.guild = this.client.guilds.cache.get(data.guild_id) || null;
        }
        if ('member' in data) {
            try {
                data.member.user = this.baseAuthor;
                data.member.id = this.baseAuthor.id;
                this.member = this.guild?.members.resolve(this.baseAuthor.id, this.guild, data.member) || null;
            }
            catch (err) { }
        }
        if (!this.webhookId && !data.author.system) {
            this.author = this.client.users.resolve(data.author.id, data.author ?? null) || null;
        }
        if (this.guild) {
            this.channel = this.guild.channels.cache.get(data.channel_id);
        }
    }
    async crosspost() {
        await __1.HTTPChannel.crossPostMessage(this.client, this.channel.id, this.id);
    }
    async delete() {
        await __1.HTTPChannel.deleteMessage(this.client, this.channel.id, this.id);
    }
    async reply(content) {
        await this.waitForAuthor();
        const msg = await __1.HTTPChannel.createMessage(this.client, this.channel.id, {
            content: content,
            message_reference: {
                message_id: this.id,
                channel_id: this.channel.id,
                fail_if_not_exists: false,
            },
        });
        return new Message(this.client, msg);
    }
    async waitForAuthor() {
        if (!this.author && !this.webhookId && !this.baseAuthor.system) {
            if (this.client.me && this.baseAuthor.id === this.client.me.id) {
                this.author = this.client.me;
            }
            else {
                this.author = await this.client.users.fetch(this.baseAuthor.id);
            }
        }
        return this;
    }
    set() {
        if (this.guild) {
            this.guild.channels.cache.get(this.channel.id).messages.cache.set(this.id, this);
        }
        return this;
    }
}
exports.default = Message;
