"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const GuildError_1 = __importDefault(require("../errors/GuildError"));
const Color_1 = __importDefault(require("../util/Color"));
class Role {
    constructor(client, data, guild) {
        this.client = null;
        this.id = null;
        this.name = null;
        this.color = null;
        this.hoist = null;
        this.icon = null;
        this.managed = null;
        this.mentionable = null;
        this.permissions = null;
        this.position = null;
        this.unicodeEmoji = null;
        if (typeof data.id !== 'string') {
            throw new GuildError_1.default('invalid role data provided');
        }
        this.client = client;
        this.id = data.id;
        this.build(data);
    }
    build(data) {
        if ('name' in data) {
            this.name = data.name;
        }
        if ('color' in data) {
            let hex = Color_1.default.intToHex(data.color);
            this.color = `#${hex === '00' ? '000000' : hex}`;
        }
        if ('hoist' in data) {
            this.hoist = data.hoist;
        }
        if ('icon' in data) {
            this.icon = data.icon;
        }
        if ('managed' in data) {
            this.managed = data.managed;
        }
        if ('mentionable' in data) {
            this.mentionable = data.mentionable;
        }
        if ('permissions' in data) {
            this.permissions = data.permissions;
        }
        if ('position' in data) {
            this.position = data.position;
        }
        if ('unicode_emoji' in data) {
            this.unicodeEmoji = data.unicode_emoji;
        }
    }
    /**
     * Set the Role's data to the cache.
     *
     * @returns {Role} This Role instance.
     * @private
     */
    set() {
        this.client.guilds.cache.set(this.id, this);
        return this;
    }
}
exports.default = Role;
