import BaseUser from "./BaseUser";
import Client from "./Client";
import Message from "./Message";
export default class User extends BaseUser {
    dmChannel: any;
    constructor(client: Client, data: any);
    private build;
    /**
     * Generate a link to the user's avatar.
     *
     * @param {Object} [options] The options to use when generating the URL.
     * @param {string} [options.format=png] The image format to use for the URL.
     * @param {boolean} [options.dynamic=false] Whether or not a GIF should be returned autoamtically if the user's avatar is animated.
     * @returns {string} The URL to the user's avatar.
     * @public
     */
    getAvatarURL(options?: {
        format?: 'png' | 'webp' | 'jpg' | 'gif';
        dynamic?: boolean;
    }): string;
    /**
     * Determine if the user's avatar is default.
     *
     * @returns {boolean} Whether or not the user's avatar is default.
     * @public
     */
    hasDefaultAvatar(): boolean;
    /**
     * Fetch this user again.
     *
     * @param {Object} [options] The options to use when fetching the user.
     * @param {boolean} [options.shouldCache=true] Whether or not to cache the result.
     * @param {boolean} [options.bypassCache=true] Whether or not to bypass the cache.
     * @returns {Promise<User>} A promise that resolves with the updated user.
     * @public
     */
    fetch(options?: {
        shouldCache?: boolean | undefined;
        bypassCache?: boolean | undefined;
    }): Promise<User>;
    /**
     * Send a message to the user.
     *
     * @param {string} [content] The content of the message.
     * @returns {Promise<Message>} A promise that resolves with the new message.
     * @public
     */
    send(content: string): Promise<Message>;
    /**
     * Set the User's data to the cache.
     *
     * @returns {User} This User instance.
     * @private
     */
    private set;
}
