"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
Object.defineProperty(exports, "__esModule", { value: true });
class BitsBlock {
    constructor(...flags) {
        this.flags = 0;
        if (flags) {
            for (let i = 0; i < flags.length; ++i)
                this.add(flags[i]);
        }
    }
    /**
     * Adds a flag (bit) to the block.
     *
     * @param {number} flags The flags to add.
     * @returns {BitsBlock} The updated block.
     * @public
     */
    add(...flags) {
        for (let i = 0; i < flags.length; ++i) {
            let flag = flags[i];
            if (!this.has(flag))
                this.flags |= flag;
        }
        return this;
    }
    /**
     * Removes a flag (bit) from the block.
     *
     * @param {number} flags The flags to remove.
     * @returns {BitsBlock} The updated block.
     * @public
     */
    remove(...flags) {
        for (let i = 0; i < flags.length; ++i) {
            let flag = flags[i];
            if (this.has(flag))
                this.flags ^= flag;
        }
        return this;
    }
    /**
     * Check if a flag (bit) is in the block.
     *
     * @param {number} flag The flag to check.
     * @returns {boolean} The result.
     * @public
     */
    has(flag) {
        return (this.flags & flag) === flag;
    }
    /**
     * Check if the block is empty.
     *
     * @returns {boolean} `true` if the block is empty, `false` otherwise.
     * @public
     */
    isEmpty() {
        return this.flags == 0;
    }
}
exports.default = BitsBlock;
