"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Cache_1 = __importDefault(require("../Cache"));
const CachedBlock_1 = __importDefault(require("./CachedBlock"));
const BaseUser_1 = __importDefault(require("../BaseUser"));
const GuildMember_1 = __importDefault(require("../GuildMember"));
const HTTPGuild_1 = __importDefault(require("../http/HTTPGuild"));
class GuildMemberBlock extends CachedBlock_1.default {
    constructor(client, guild, options) {
        super(client, new Cache_1.default(options));
        this.guild = null;
        this.guild = guild;
    }
    async fetch(userId, options) {
        options = options || {};
        options.shouldCache = options.shouldCache ?? true;
        options.bypassCache = options.bypassCache ?? false;
        if (!options.bypassCache) {
            const cached = this.cache.get(userId);
            if (cached)
                return cached;
        }
        let member = await HTTPGuild_1.default.getMember(this.client, this.guild.id, userId);
        member = new GuildMember_1.default(this.client, member, this.guild);
        if (options.shouldCache)
            member._set();
        return member;
    }
    resolve(user, guild, def) {
        if (user instanceof BaseUser_1.default) {
            return this.cache.get(user.id) ?? user;
        }
        else if (typeof user === 'string') {
            if (def)
                return this.cache.get(user) ?? new GuildMember_1.default(this.client, def, guild);
            else
                return this.cache.get(user) ?? null;
        }
        else {
            return null;
        }
    }
}
exports.default = GuildMemberBlock;
