"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Cache_1 = __importDefault(require("../Cache"));
const CachedBlock_1 = __importDefault(require("./CachedBlock"));
const ClientUser_1 = __importDefault(require("../ClientUser"));
const HTTPUser_1 = __importDefault(require("../http/HTTPUser"));
const User_1 = __importDefault(require("../User"));
const BaseUser_1 = __importDefault(require("../BaseUser"));
class UserBlock extends CachedBlock_1.default {
    constructor(client, options) {
        super(client, new Cache_1.default(options));
    }
    async fetchMe() {
        let user = await HTTPUser_1.default.getCurrent(this.client);
        user = new ClientUser_1.default(this.client, user);
        this.cache.set(user.id, user);
        return user;
    }
    async fetch(userId, options) {
        options = options || {};
        options.shouldCache = options.shouldCache ?? true;
        options.bypassCache = options.bypassCache ?? false;
        if (!options.bypassCache) {
            const cached = this.cache.get(userId);
            if (cached)
                return cached;
        }
        let user = await HTTPUser_1.default.get(this.client, userId);
        user = new User_1.default(this.client, user);
        if (options.shouldCache)
            user['set']();
        return user;
    }
    resolve(user, def) {
        if (user instanceof BaseUser_1.default)
            return this.cache.get(user.id) ?? user;
        else if (typeof user === 'string') {
            if (def)
                return this.cache.get(user) ?? new User_1.default(this.client, def);
            else
                return this.cache.get(user) ?? null;
        }
        else
            return null;
    }
}
exports.default = UserBlock;
