"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.translateError = void 0;
const petitio_1 = __importDefault(require("petitio"));
const util_1 = require("util");
const DiscordAPIError_1 = __importDefault(require("../../errors/DiscordAPIError"));
class Request {
    constructor(client, method, path, body) {
        this.client = null;
        this.method = null;
        this.url = null;
        this.body = null;
        this.reason = null;
        this.response = null;
        this.client = client;
        this.method = method;
        this.url = `https://discord.com/api/v9${path}`;
        this.body = body ?? null;
    }
    async make() {
        let req = (0, petitio_1.default)(this.url, this.method)
            .timeout(5000)
            .header({
            'Authorization': `Bot ${this.client.token}`,
            'User-Agent': `DiscordBot (https://birb.js.org, ${require('../../package.json').version})`,
        });
        if (this.body) {
            req.header('Content-Type', 'application/json; charset=utf-8');
            req.body(this.body);
        }
        if (this.reason)
            req.header('X-Audit-Log-Reason', this.reason);
        let res;
        let body;
        try {
            res = await req.send();
            body = res.json();
        }
        catch (err) {
            console.error(err);
            throw new DiscordAPIError_1.default(`failed to make ${this.method} request to ${this.url}`);
        }
        if (body && body.code !== undefined) {
            console.log((0, util_1.inspect)(body, { depth: null }));
            throw new DiscordAPIError_1.default(`[${this.method}:${this.url}] ${body.code}: ${translateError(body.code, body.message)}`);
        }
        if (!res.statusCode || res.statusCode > 299) {
            throw new DiscordAPIError_1.default(`encountered HTTP error ${res.statusCode} whilst sending ${this.method} request to ${this.url}`);
        }
        return body;
    }
}
exports.default = Request;
function translateError(code, message) {
    if (!message)
        return 'internal Discord API Error (not your fault)';
    if (code == 50013)
        return `Missing Permissions: your bot does not have permission to perform this action; ensure at least one of its roles has the permissions required`;
    else
        return message;
}
exports.translateError = translateError;
