"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
/**
 * The ShardChild is just a class to make it easier for the
 * ShardMaster do perform actions on individual shards.
 */
class ShardChild {
    constructor(master, shardNumber) {
        this.master = null;
        this.number = null;
        this.process = null;
        this.events = {};
        this.master = master;
        this.number = shardNumber;
    }
    async start() {
        this.process = (0, child_process_1.fork)(this.master.modulePath, {
            env: {
                BIRB_IS_SHARD: 'true',
                BIRB_SHARD_NUMBER: this.number.toString(),
                BIRB_COMMUNICATE_VIA: 'ipc',
            }
        });
        this.process.on('message', this.onMessage.bind(this));
        this.process.on('exit', this.onExit.bind(this));
    }
    listen(event, callback) {
        this.events[event] = callback;
    }
    emit(event, ...args) {
        if (this.events[event])
            this.events[event](...args);
    }
    /**
     * Send an IPC message to the shard's child process.
     *
     * @param {any} data The data to send.
     */
    send(data) {
        if (this.process)
            this.process.send(data);
    }
    onMessage(message) {
        switch (message.event) {
            case 'BIRB_BROADCAST_EVAL':
                this.master['shardToShardBroadcast'](this, {
                    event: 'BIRB_EVAL',
                    messageId: message.data.messageId,
                    eval: message.data.eval,
                });
                break;
            default:
                this.emit(message.event, message.data);
        }
    }
    onExit(code, signal) {
        this.process = null;
        this.emit('exit', code, signal);
    }
}
exports.default = ShardChild;
