import ShardChild from './ShardChild';
import Crypit from 'crypit';
/**
 * The ShardMaster is used to dynamically manage and spawn
 * shards (which are child processes). To provide info to a
 * shard about it's environment, the ShardMaster should use
 * environment variables. After the shard is spawned,
 * continious communication between the ShardMaster and the
 * shard is done through the IPC channel. Shards interact
 * with the ShardMaster through methods on their own Shard
 * class (which ultimately just sends JSON IPC messages).
 */
export default class ShardMaster {
    token: string;
    totalShards: number;
    apiVersion: number;
    modulePath: string;
    children: ShardChild[];
    crypit: Crypit;
    private events;
    /**
     *
     * @param {string} pathToIndex The path to your bot's main file
     * @param {object} options The sharding options
     * @param {number} options.token Your bot's token (this is required)
     * @param {number} [options.apiVersion=9] The Discord API version to use
     */
    constructor(pathToIndex: string, options: {
        token: string;
        apiVersion?: number;
    });
    /**
     * Start the automatic spawning process.
     */
    start(): Promise<void>;
    spawn(shard: number): Promise<ShardChild>;
    listen(event: string, listener: (...args: any[]) => any): void;
    emit(event: string, ...args: any[]): void;
    protected shardToShardBroadcast(shard: ShardChild, data: {
        [key: string]: any;
    }): void;
}
