"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ShardChild_1 = __importDefault(require("./ShardChild"));
const petitio_1 = __importDefault(require("petitio"));
const crypit_1 = __importDefault(require("crypit"));
/**
 * The ShardMaster is used to dynamically manage and spawn
 * shards (which are child processes). To provide info to a
 * shard about it's environment, the ShardMaster should use
 * environment variables. After the shard is spawned,
 * continious communication between the ShardMaster and the
 * shard is done through the IPC channel. Shards interact
 * with the ShardMaster through methods on their own Shard
 * class (which ultimately just sends JSON IPC messages).
 */
class ShardMaster {
    /**
     *
     * @param {string} pathToIndex The path to your bot's main file
     * @param {object} options The sharding options
     * @param {number} options.token Your bot's token (this is required)
     * @param {number} [options.apiVersion=9] The Discord API version to use
     */
    constructor(pathToIndex, options) {
        this.token = null;
        this.totalShards = 1;
        this.apiVersion = null;
        this.modulePath = null;
        this.children = [];
        this.crypit = null;
        this.events = {};
        this.modulePath = pathToIndex;
        this.token = options?.token;
        this.apiVersion = options?.apiVersion ?? 9;
        this.crypit = new crypit_1.default();
    }
    /**
     * Start the automatic spawning process.
     */
    async start() {
        let req = (0, petitio_1.default)(`https://discord.com/api/v${this.apiVersion}/gateway/bot`, 'GET')
            .timeout(10000)
            .header({
            'Authorization': `Bot ${this.token}`,
            'User-Agent': `DiscordBot (https://birb.js.org, ${require('../../package.json').version})`,
            'Content-Type': 'application/json; charset=utf-8',
            'Accept': 'application/json',
        });
        let res = await req.send();
        let bot = res.json();
        if (!bot || !bot.shards)
            throw new Error('sharding failed; couldn\'t get recommended shard count from Discord');
        this.totalShards = bot.shards;
        for (let i = 0; i < this.totalShards; ++i) {
            await this.spawn(i);
        }
    }
    async spawn(shard) {
        let child = new ShardChild_1.default(this, shard);
        this.children.push(child);
        await child.start();
        return child;
    }
    listen(event, listener) {
        this.events[event] = listener;
    }
    emit(event, ...args) {
        if (this.events[event])
            this.events[event](...args);
    }
    shardToShardBroadcast(shard, data) {
        for (let child of this.children) {
            if (child.number === shard.number)
                continue;
            child.send(data);
        }
    }
}
exports.default = ShardMaster;
